@@ -1,5 +1,5 @@
 from __future__ import unicode_literals
-
+import base64
 
 from dataplicity.app.subcommand import SubCommand
 from dataplicity.client.serial import get_default_serial
@@ -52,6 +52,105 @@ path = {FIRMWARE_PATH}
 
 """
 
+rpi_conf_template = """
+[extend]
+conf = /etc/dataplicity/dataplicity.conf
+
+[server]
+push_url = http://sync.dataplicity.com/pushwait
+
+[device]
+class = Master RPI
+serial = {SERIAL}
+
+[samplers]
+path = /tmp/samplers/
+
+[task:proc]
+run = dataplicity.tasks.system.ProcessList
+poll = 30
+data-timeline = process_list
+
+[task:cpu_percent]
+run = dataplicity.tasks.system.CPUPercentSampler
+poll = 30
+data-sampler = cpu_percent
+
+[task:memory_available]
+run = dataplicity.tasks.system.AvailableMemorySampler
+poll = 30
+data-sampler = memory_available
+
+[task:memory_total]
+run = dataplicity.tasks.system.TotalMemorySampler
+poll = 30
+data-sampler = memory_total
+
+[task:disk_available]
+run = dataplicity.tasks.system.AvailableDisk
+poll = 30
+data-sampler = disk_available
+
+[task:disk_total]
+run = dataplicity.tasks.system.TotalDisk
+poll = 30
+data-sampler = disk_total
+
+[task:network]
+run = dataplicity.tasks.system.NetworkSampler
+poll = 30
+data-timeline = network
+
+[task:ifconfig]
+run = dataplicity.tasks.system.IfconfigData
+poll = 30
+data-timeline = ifconfig
+
+[task:sysinfo]
+run = dataplicity.tasks.system.SystemInfo
+poll = 60
+data-timeline = sysinfo
+
+[task:installedpackages]
+run = dataplicity.tasks.system.InstalledPackages
+poll = 300
+data-timeline = installed_packages
+
+[task:setgpio]
+run = dataplicity.tasks.rpi.SetGPIO
+poll = 30
+
+[settings:gpio]
+defaults = ./gpio.ini
+
+[timeline:process_list]
+[timeline:cpu_percent]
+[timeline:network]
+[timeline:ifconfig]
+[timeline:sysinfo]
+[timeline:installed_packages]
+
+[sampler:memory_available]
+[sampler:memory_total]
+[sampler:disk_available]
+[sampler:disk_total]
+[sampler:cpu_percent]
+"""
+
+
+gpio_ini_template = """
+[pins]
+pin22 = ignore
+pin18 = ignore
+pin16 = ignore
+pin15 = ignore
+pin13 = ignore
+pin12 = ignore
+pin11 = ignore
+pin7 = ignore
+"""
+
+
 
 class Init(SubCommand):
     """Initialize this device for first use.
@@ -88,17 +187,19 @@ class Init(SubCommand):
                             help="auto-register online")
         parser.add_argument('--subdomain', dest="subdomain", required=False, default='', metavar="SUBDOMAIN",
                             help="Your company subdomain, if using --auto")
+        parser.add_argument('--rpi', dest='rpi', action='store_true', help="init rpi device")
+        parser.add_argument('--usercode', dest='usercode', action='store', help="base64 encoded usercode")
 
     def run(self):
         args = self.args
         auto = args.auto
 
         user = args.user
-        if user is None and not auto:
+        if user is None and not auto and not args.rpi:
             user = raw_input('username: ')
 
         password = args.password
-        if password is None and not auto:
+        if password is None and not auto and not args.rpi:
             import getpass
             password = getpass.getpass('password: ')
 
@@ -112,8 +213,11 @@ class Init(SubCommand):
 
         output_dir = args.output
         device_conf_path = os.path.join(output_dir, 'dataplicity.conf')
-
+        if args.rpi:
+            rpi_device_conf_path = '/opt/dataplicity/dataplicity.conf'
+            gpio_conf_path = '/opt/dataplicity/gpio.ini'
         serial = args.serial
+
         name = args.name
         if serial is None:
             serial = get_default_serial()
@@ -140,10 +244,15 @@ class Init(SubCommand):
                     sys.stderr.write("do you need to run this command with 'sudo'?\n")
                     return -1
         else:
-            auth_token = remote.call('device.auth',
-                                     serial=serial,
-                                     username=user,
-                                     password=password)
+            if args.rpi:
+                print 'authenticating raspberry pi'
+                auth_token, serial = remote.call('device.auth_rpi',
+                                                 usercode=args.usercode)
+            else:
+                auth_token = remote.call('device.auth',
+                                         serial=serial,
+                                         username=user,
+                                         password=password)
             sys.stdout.write('device authenticated\n')
 
         FIRMWARE_CONF_PATH = os.path.join(constants.FIRMWARE_PATH, 'current/dataplicity.conf')
@@ -152,12 +261,14 @@ class Init(SubCommand):
                          "class": args.cls or 'default',
                          "auth_token": auth_token,
                          "auto_device_text": auto,
-                         "subdomain": auto_device_subdomain,
+                         "subdomain": auto_device_subdomain or '',
                          "SERVER_URL": args.server or constants.SERVER_URL,
                          "SETTINGS_PATH": constants.SETTINGS_PATH,
                          "FIRMWARE_PATH": constants.FIRMWARE_PATH,
                          "FIRMWARE_CONF_PATH": FIRMWARE_CONF_PATH}
         conf_contents = conf_template.format(**template_data)
+        if args.rpi:
+            rpi_conf_contents = rpi_conf_template.format(SERIAL=serial)
 
         if os.path.exists(device_conf_path) and not (args.force or args.dry):
             sys.stderr.write("a file called \"{}\" exists. Use --force to overwrite\n".format(device_conf_path))
@@ -190,6 +301,9 @@ class Init(SubCommand):
             sys.stdout.write("wrote {}\n".format(path))
 
         write_conf(device_conf_path, conf_contents)
+        if args.rpi:
+            write_conf(rpi_device_conf_path, rpi_conf_contents)
+            write_conf(gpio_conf_path, gpio_ini_template)
 
         for path in (constants.SETTINGS_PATH, constants.FIRMWARE_PATH):
             if not os.path.exists(path):
